editors Package
===============

:mod:`editors` Package
----------------------

.. automodule:: stoqlib.gui.editors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`accounteditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.accounteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`accounttransactioneditor` Module
--------------------------------------

.. automodule:: stoqlib.gui.editors.accounttransactioneditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`addresseditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.addresseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backupsettings` Module
----------------------------

.. automodule:: stoqlib.gui.editors.backupsettings
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`baseeditor` Module
------------------------

.. automodule:: stoqlib.gui.editors.baseeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`callseditor` Module
-------------------------

.. automodule:: stoqlib.gui.editors.callseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`categoryeditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.categoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`clientcategoryeditor` Module
----------------------------------

.. automodule:: stoqlib.gui.editors.clientcategoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`contacteditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.contacteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`costcentereditor` Module
------------------------------

.. automodule:: stoqlib.gui.editors.costcentereditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`creditcheckhistoryeditor` Module
--------------------------------------

.. automodule:: stoqlib.gui.editors.creditcheckhistoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`crediteditor` Module
--------------------------------------

.. automodule:: stoqlib.gui.editors.crediteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`deliveryeditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.deliveryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`deviceseditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.deviceseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`discounteditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.discounteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fiscaleditor` Module
--------------------------

.. automodule:: stoqlib.gui.editors.fiscaleditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`formfieldeditor` Module
-----------------------------

.. automodule:: stoqlib.gui.editors.formfieldeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`grideditor` Module
------------------------

.. automodule:: stoqlib.gui.editors.grideditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventoryadjustmenteditor` Module
---------------------------------------

.. automodule:: stoqlib.gui.editors.inventoryadjustmenteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventoryeditor` Module
-----------------------------

.. automodule:: stoqlib.gui.editors.inventoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`invoiceeditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.invoiceeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`invoiceitemeditor` Module
-------------------------------

.. automodule:: stoqlib.gui.editors.invoiceitemeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loanitemeditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.loanitemeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`noteeditor` Module
------------------------

.. automodule:: stoqlib.gui.editors.noteeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parameterseditor` Module
------------------------------

.. automodule:: stoqlib.gui.editors.parameterseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentcategoryeditor` Module
-----------------------------------

.. automodule:: stoqlib.gui.editors.paymentcategoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymenteditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.paymenteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentmethodeditor` Module
---------------------------------

.. automodule:: stoqlib.gui.editors.paymentmethodeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentseditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.paymentseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`personeditor` Module
--------------------------

.. automodule:: stoqlib.gui.editors.personeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`preferenceseditor` Module
-------------------------------

.. automodule:: stoqlib.gui.editors.preferenceseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`producteditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.producteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productioneditor` Module
------------------------------

.. automodule:: stoqlib.gui.editors.productioneditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`profileeditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.profileeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchaseeditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.purchaseeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`saleeditor` Module
------------------------

.. automodule:: stoqlib.gui.editors.saleeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellableeditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.sellableeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellableuniteditor` Module
--------------------------------

.. automodule:: stoqlib.gui.editors.sellableuniteditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`serviceeditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.serviceeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`shortcutseditor` Module
-----------------------------

.. automodule:: stoqlib.gui.editors.shortcutseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stationeditor` Module
---------------------------

.. automodule:: stoqlib.gui.editors.stationeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreaseeditor` Module
---------------------------------

.. automodule:: stoqlib.gui.editors.stockdecreaseeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`taxclasseditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.taxclasseditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tilleditor` Module
------------------------

.. automodule:: stoqlib.gui.editors.tilleditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transfereditor` Module
----------------------------

.. automodule:: stoqlib.gui.editors.transfereditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`workordercategoryeditor` Module
-------------------------------------

.. automodule:: stoqlib.gui.editors.workordercategoryeditor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`workordereditor` Module
-----------------------------

.. automodule:: stoqlib.gui.editors.workordereditor
    :members:
    :undoc-members:
    :show-inheritance:
